@@ -310,7 +310,12 @@ class Github(Base):
     @classmethod
     @LoggedFunction(logger)
     def upload_asset(
-        cls, owner: str, repo: str, release_id: int, file: str, label: str = None
+        cls,
+        owner: str,
+        repo: str,
+        release_id: int,
+        file: str,
+        label: Optional[str] = None,
     ) -> bool:
         """Upload an asset to an existing release
 
@@ -586,7 +591,12 @@ class Gitea(Base):
     @classmethod
     @LoggedFunction(logger)
     def upload_asset(
-        cls, owner: str, repo: str, release_id: int, file: str, label: str = None
+        cls,
+        owner: str,
+        repo: str,
+        release_id: int,
+        file: str,
+        label: Optional[str] = None,
     ) -> bool:
         """Upload an asset to an existing release
 
